Python SDK for GOPLUSPLATFORM 
=============================

`GOPLUSPLATFORM <http://goplusplatform.com>`is a cloud based platform that helps young developers to connect different types of IoT devices and create smart services in real time. The platform provides an intuitive user interface for adding and managing devices, simple event-driven logig rules and API for third-party developers. IoT developers can utilize GOPLUSPLATFORM as the backend infrastructure throughout the entire service development cycle, from prototyping to product launch.

This Package provide functions for connecting IoT devices (such as Raspberry Pi or Intel Edison) to platform.
